aboutsummaryrefslogtreecommitdiff
path: root/libbuild2/algorithm.hxx
diff options
context:
space:
mode:
authorBoris Kolpackov <boris@codesynthesis.com>2022-03-09 11:13:05 +0200
committerBoris Kolpackov <boris@codesynthesis.com>2022-03-09 11:13:05 +0200
commit145589cf2b524b59a8ffa950882d3433e2885b7c (patch)
treef3db3dee01d39e72f7033171c34d1fe7403da490 /libbuild2/algorithm.hxx
parent2e6c3bf33ab1cd75b9936e65568a39571f279fc3 (diff)
Rename execute_wait() to execute()
The old half-way semantics of execute() wasn't useful.
Diffstat (limited to 'libbuild2/algorithm.hxx')
-rw-r--r--libbuild2/algorithm.hxx21
1 files changed, 7 insertions, 14 deletions
diff --git a/libbuild2/algorithm.hxx b/libbuild2/algorithm.hxx
index f6c296e..b472603 100644
--- a/libbuild2/algorithm.hxx
+++ b/libbuild2/algorithm.hxx
@@ -537,27 +537,20 @@ namespace build2
// Execute the action on target, assuming a rule has been matched and the
// recipe for this action has been set. This is the synchrounous executor
- // implementation (but may still return target_state::busy if the target
- // is already being executed). Decrements the dependents count.
- //
- // Note: does not translate target_state::failed to the failed exception.
- //
- target_state
- execute (action, const target&);
-
- // As above but wait for completion if the target is busy and translate
- // target_state::failed to the failed exception.
+ // implementation that waits for completion if the target is already being
+ // executed. Translate target_state::failed to the failed exception unless
+ // fail is false.
//
target_state
- execute_wait (action, const target&);
+ execute (action, const target&, bool fail = true);
// As above but start asynchronous execution. Return target_state::unknown
// if the asynchrounous execution has been started and target_state::busy if
// the target has already been busy.
//
- // If fail is false, then return target_state::failed if the target match
- // failed. Otherwise, throw the failed exception if keep_going is false and
- // return target_state::failed otherwise.
+ // If fail is false, then return target_state::failed if the target
+ // execution failed. Otherwise, throw the failed exception if keep_going is
+ // false and return target_state::failed otherwise.
//
target_state
execute_async (action, const target&,